/**********************************************************/
/*                                                        */
/*   File Name    :  DataPlus.H                           */
/*                                                        */
/*   Component    :  DataPlus Error Codes and Prototypes  */
/*                                                        */
/*   Product      :  DataPlus 'C' Library                 */
/*                                                        */
/*   Author       :  Andy Dransfield                      */
/*                                                        */
/*   Version history                                      */
/*                                                        */
/*   01 : December  1990                                  */
/*   02 : October   1991                                  */
/*   03 : January   1992                                  */
/*                                                        */
/**********************************************************/
/*                                                        */
/*   This program has been created by Andy Dransfield.    */
/*   It may not be copied (in whole or in part) without   */
/*   the prior written permission of the Author.          */
/*                                                        */
/**********************************************************/

#define EVALUATION_VERSION        -11
#define DATABASE_ALREADY_OPEN     -12
#define INVALID_DIRECTORY         -13
#define UNKNOWN_DATABASE          -14
#define DATABASE_LOCKED           -15
#define INVALID_USER_NAME         -16
#define INVALID_PASSWORD          -17
#define DATABASE_NOT_OPEN         -18
#define TOO_MANY_OPEN_FILES       -19
#define UNKNOWN_FORM              -21
#define INVALID_FORM_NUMBER       -22
#define FORM_NOT_OPEN             -23
#define NO_FORM_ATTRIBUTES        -24
#define UNKNOWN_FIELD             -31
#define INVALID_FIELD_NUMBER      -32
#define FIELD_NOT_INDEXED         -33
#define VIRTUAL_FIELD             -34
#define FIELD_NOT_CHOICE          -35
#define INVALID_CHOICE_NUMBER     -36
#define FIELD_TYPE_MISMATCH       -37
#define FIELD_NOT_NUMERIC         -38
#define SECURITY_ACCESS_DENIED    -39
#define FIELD_BLANK               -40
#define REQUIRED_FIELD_BLANK      -41
#define RECORD_NOT_UNIQUE         -42
#define MATCHING_KEY_NOT_FOUND    -43
#define NO_CURRENT_RECORD         -44
#define RECORD_DELETED            -51
#define END_OF_FILE               -59
#define MEMORY_ALLOCATION_FAILURE -71
#define SYSTEM_ERROR              -99

#ifdef __cplusplus
//  Specify C++ style linkage
extern "C"
{
#endif
    int   DP_open_database               (const char *, char);
    int   DP_user_sign_on                (const char *, const char *);
    int   DP_load_form_attributes        (const char *);
    int   DP_clear_form_attributes       (const char *);
    int   DP_user_screen_style           (char *);
    int   DP_user_startup_menu           (char *);
    int   DP_user_help_level             (void);
    int   DP_close_database              (void);
    int   DP_increase_file_handles       (int);

    int   DP_open_form                   (const char *);
    int   DP_close_form                  (const char *);
    int   DP_reorganize_form             (const char *);
    int   DP_purge_form                  (const char *);

    long  DP_read_record                 (const char *, unsigned long);
    long  DP_read_first_record           (const char *);
    long  DP_read_previous_record        (const char *);
    long  DP_read_next_record            (const char *);
    long  DP_read_last_record            (const char *);
    long  DP_save_record                 (const char *);
    long  DP_modify_record               (const char *);
    int   DP_delete_record               (const char *);
    int   DP_clear_record                (const char *);
    int   DP_retrieve_default_record     (const char *);

    long  DP_read_indexed_record         (const char *, const char *, const void *);
    long  DP_read_first_indexed_record   (const char *, const char *);
    long  DP_read_next_indexed_record    (const char *, const char *);
    long  DP_read_last_indexed_record    (const char *, const char *);
    char  DP_get_index_scheme            (const char *, const char *);
    int   DP_set_index_scheme            (const char *, const char *, int);
    int   DP_reorganize_index            (const char *, const char *);

    int   DP_get_field                   (const char *, const char *, void *);
    int   DP_get_field_choice            (const char *, const char *, char *);
    int   DP_put_field                   (const void *, const char *, const char *);
    int   DP_move_field                  (const char *, const char *, const char *, const char *);
    int   DP_compare_field               (const char *, const char *, const void *);
    int   DP_compare_fields              (const char *, const char *, const char *, const char *);
    int   DP_clear_field                 (const char *, const char *);
    int   DP_retrieve_default_field      (const char *, const char *);

    int   DP_DataEase_version            (void);
    int   DP_database_name               (char *);
    int   DP_maximum_forms               (void);
    int   DP_form_name                   (int, char *);
    long  DP_active_records              (const char *);
    long  DP_deleted_records             (const char *);
    long  DP_existing_records            (const char *);
    int   DP_form_view_security          (const char *);
    int   DP_form_modify_security        (const char *);
    int   DP_form_enter_security         (const char *);
    int   DP_form_delete_security        (const char *);
    int   DP_form_help                   (const char *, char * []);
    int   DP_maximum_fields              (const char *);
    int   DP_field_name                  (const char *, int, char *);
    int   DP_field_type                  (const char *, const char *);
    int   DP_field_number_type           (const char *, const char *);
    int   DP_field_display_size          (const char *, const char *);
    int   DP_field_significant_digits    (const char *, const char *);
    char  DP_field_data_type             (const char *, const char *);
    int   DP_field_size                  (const char *, const char *);
    int   DP_maximum_field_choices       (const char *, const char *);
    int   DP_field_choice_size           (const char *, const char *);
    int   DP_field_choice_name           (const char *, const char *, unsigned char, char * []);
    char  DP_field_attributes            (const char *, const char *);
    int   DP_field_derivation            (const char *, const char *, char * []);
    int   DP_field_range                 (const char *, const char *, char * [], char * []);
    int   DP_field_view_security         (const char *, const char *);
    int   DP_field_write_security        (const char *, const char *);
    int   DP_field_help                  (const char *, const char *, char * []);
    int   DP_field_colour                (const char *, const char *);

    int   DP_first_error                 (void);
    int   DP_last_error                  (void);
    char *DP_first_error_call            (void);
    char *DP_last_error_call             (void);
    void  DP_first_perror                (const char *);
    void  DP_last_perror                 (const char *);
    void  DP_perror                      (const char *, int);
    char *DP_error_message               (int);

#ifdef __cplusplus
};
#endif
